Finite State Automata for streams
=================================

This is a library for running Finite State Automata (FSA)
on bound and unbound streams of event.

An online documentation is available at:
http://fsa4streams.readthedocs.org/en/latest/?badge=latest

.. image:: https://readthedocs.org/projects/fsa4streams/badge/?version=latest
   :target: http://fsa4streams.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status
                

Ideas for future extensions
---------------------------

* export to dot (for graphical presentation)
* toolkit for handling FSA's
  - optimizing
  - merging
* more built-in matchers?
  - prefix
  - more flexible regexp (i.e. not enforcing ^ and $)
* converter of regexp to automata
